<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:16:13
         compiled from "ls:viewSearch.tpl" */ ?>
<?php /*%%SmartyHeaderCode:11872149665851704da546b6-48539311%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '7e5e1b40a6897e6cd2a4b75f034a469f40dd849c' => 
    array (
      0 => 'ls:viewSearch.tpl',
      1 => 1472212472,
      2 => 'ls',
    ),
  ),
  'nocache_hash' => '11872149665851704da546b6-48539311',
  'function' => 
  array (
  ),
  'variables' => 
  array (
    'searchForm' => 0,
    'name' => 0,
    'value' => 0,
    'pagetitle' => 0,
    'LSview_actions' => 0,
    'item' => 0,
    'label' => 0,
    'LSsearch' => 0,
    'conf' => 0,
    'cid' => 0,
    'page' => 0,
    'object' => 0,
    'start' => 0,
    'i' => 0,
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.21-dev',
  'unifunc' => 'content_5851704db02551_04783770',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_5851704db02551_04783770')) {function content_5851704db02551_04783770($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
if (!is_callable('smarty_function_cycle')) include '/usr/share/php/smarty3/plugins/function.cycle.php';
?><?php echo $_smarty_tpl->getSubTemplate ('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>

<form action='<?php echo $_smarty_tpl->tpl_vars['searchForm']->value['action'];?>
' method='post' class='LSview_search' id='LSsearch_form'>

<div class='LSview_search'>
  <?php  $_smarty_tpl->tpl_vars['value'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['value']->_loop = false;
 $_smarty_tpl->tpl_vars['name'] = new Smarty_Variable;
 $_from = $_smarty_tpl->tpl_vars['searchForm']->value['hiddenFields']; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['value']->key => $_smarty_tpl->tpl_vars['value']->value) {
$_smarty_tpl->tpl_vars['value']->_loop = true;
 $_smarty_tpl->tpl_vars['name']->value = $_smarty_tpl->tpl_vars['value']->key;
?>
    <input type='hidden' name='<?php echo $_smarty_tpl->tpl_vars['name']->value;?>
' value='<?php echo $_smarty_tpl->tpl_vars['value']->value;?>
' />
  <?php } ?>
  
  <input type='text' name='pattern' class='LSview_search' value="<?php echo $_smarty_tpl->tpl_vars['searchForm']->value['values']['pattern'];?>
"/>
  <input type='submit' value='<?php echo $_smarty_tpl->tpl_vars['searchForm']->value['labels']['submit'];?>
' name='<?php echo $_smarty_tpl->tpl_vars['searchForm']->value['names']['submit'];?>
' class='LSview_search' />
  <p id='LSview_search_param'>
    <label class='LSview_search'><?php echo $_smarty_tpl->tpl_vars['searchForm']->value['labels']['approx'];?>
 : <input type='checkbox' name='approx' class='LSview_search' <?php if ($_smarty_tpl->tpl_vars['searchForm']->value['values']['approx']!='') {?>checked="true"<?php }?> /></label>
    <?php if ($_smarty_tpl->tpl_vars['searchForm']->value['recursive']) {?><label class='LSview_search'><?php echo $_smarty_tpl->tpl_vars['searchForm']->value['labels']['recursive'];?>
 : <input type='checkbox' name='recursive' class='LSview_search' <?php if ($_smarty_tpl->tpl_vars['searchForm']->value['values']['recursive']!='') {?>checked="true"<?php }?>/></label><?php }?>
  </p>
</div>

<h1>
  <?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;?>

</h1>

<?php if ($_smarty_tpl->tpl_vars['LSview_actions']->value!='') {?>
<ul class='LSview-actions'>
  <?php  $_smarty_tpl->tpl_vars['item'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['item']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['LSview_actions']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['item']->key => $_smarty_tpl->tpl_vars['item']->value) {
$_smarty_tpl->tpl_vars['item']->_loop = true;
?>
    <?php if (is_array($_smarty_tpl->tpl_vars['item']->value)) {?>
      <li class='LSview-actions'><a href='<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
' class='LSview-actions'><img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
' alt='<?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
' title='<?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
' /> <?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['item']->value['label']),$_smarty_tpl);?>
</a></li>
    <?php }?>
  <?php } ?>
</ul>
<?php }?>

<?php if (count($_smarty_tpl->tpl_vars['LSsearch']->value->predefinedFilters)!=0) {?>
  <select id='LSview_search_predefinedFilter' name='predefinedFilter'>
    <option value=''>--</option>
    <?php echo smarty_function_html_options(array('options'=>$_smarty_tpl->tpl_vars['LSsearch']->value->predefinedFilters,'selected'=>$_smarty_tpl->tpl_vars['searchForm']->value['predefinedFilter']),$_smarty_tpl);?>

  </select>
<?php }?>


</form>

<table class='LSobject-list'>
    <tr class='LSobject-list'>
      <th class='LSobject-list'>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
        <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;sortBy=displayName&amp;nocache=<?php echo time();?>
'>
          <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sortBy=='displayName') {?>
            <strong><?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_objectName;?>
</strong>
            <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection),$_smarty_tpl);?>
' class='LSobject-list-ordersense' alt='<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection;?>
'/>
          <?php } else { ?>
            <?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_objectName;?>

          <?php }?>
        </a>
        <?php } else { ?>
          <?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_objectName;?>

        <?php }?>
      </th>
      <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->displaySubDn) {?>
        <th class='LSobject-list LSobject-list-subdn'>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
          <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;sortBy=subDn&amp;nocache=<?php echo time();?>
'>
          <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sortBy=='subDn') {?>
            <strong><?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_level;?>
</strong>
            <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection),$_smarty_tpl);?>
' class='LSobject-list-ordersense' alt='<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection;?>
'/>
          <?php } else { ?>
            <?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_level;?>

          <?php }?>
          </a>
        <?php } else { ?>
          <?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_level;?>

        <?php }?>
        </th>
      <?php }?>
      <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {?>
        <?php  $_smarty_tpl->tpl_vars['conf'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['conf']->_loop = false;
 $_smarty_tpl->tpl_vars['cid'] = new Smarty_Variable;
 $_from = $_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['conf']->key => $_smarty_tpl->tpl_vars['conf']->value) {
$_smarty_tpl->tpl_vars['conf']->_loop = true;
 $_smarty_tpl->tpl_vars['cid']->value = $_smarty_tpl->tpl_vars['conf']->key;
?>
        <th class='LSobject-list'<?php if ($_smarty_tpl->tpl_vars['conf']->value['cssStyle']) {?> style="<?php echo $_smarty_tpl->tpl_vars['conf']->value['cssStyle'];?>
"<?php }?>>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
          <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;sortBy=<?php echo $_smarty_tpl->tpl_vars['cid']->value;?>
&amp;nocache=<?php echo time();?>
'>
          <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sortBy==$_smarty_tpl->tpl_vars['cid']->value) {?>
            <strong><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['conf']->value['label']),$_smarty_tpl);?>
</strong>
            <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection),$_smarty_tpl);?>
' class='LSobject-list-ordersense' alt='<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection;?>
'/>
          <?php } else { ?>
            <?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['conf']->value['label']),$_smarty_tpl);?>

          <?php }?>
          </a>
        <?php } else { ?>
          <?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['conf']->value['label']),$_smarty_tpl);?>

        <?php }?>
        </th>
        <?php } ?>
      <?php }?>
      <th class='LSobject-list'><?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_actions;?>
</th>
    </tr>
    <?php  $_smarty_tpl->tpl_vars['object'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['object']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['page']->value['list']; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['object']->key => $_smarty_tpl->tpl_vars['object']->value) {
$_smarty_tpl->tpl_vars['object']->_loop = true;
?>
    <tr class='<?php echo smarty_function_cycle(array('values'=>"LSobject-list,LSobject-list LSobject-list-bis"),$_smarty_tpl);?>
'>
        <td class='LSobject-list LSobject-list-names'><a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;dn=<?php echo rawurlencode($_smarty_tpl->tpl_vars['object']->value->dn);?>
'  class='LSobject-list'><?php echo $_smarty_tpl->tpl_vars['object']->value->displayName;?>
</a> </td>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->displaySubDn) {?><td class='LSobject-list'><?php echo $_smarty_tpl->tpl_vars['object']->value->subDn;?>
</td><?php }?>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {?>
          <?php  $_smarty_tpl->tpl_vars['conf'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['conf']->_loop = false;
 $_smarty_tpl->tpl_vars['cid'] = new Smarty_Variable;
 $_from = $_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['conf']->key => $_smarty_tpl->tpl_vars['conf']->value) {
$_smarty_tpl->tpl_vars['conf']->_loop = true;
 $_smarty_tpl->tpl_vars['cid']->value = $_smarty_tpl->tpl_vars['conf']->key;
?>
          <td class='LSobject-list'<?php if ($_smarty_tpl->tpl_vars['conf']->value['cssStyle']) {?> style="<?php echo $_smarty_tpl->tpl_vars['conf']->value['cssStyle'];?>
"<?php }?>><?php echo $_smarty_tpl->tpl_vars['object']->value->{$_smarty_tpl->tpl_vars['cid']->value};?>
</td>
          <?php } ?>
        <?php }?>
        <td class='LSobject-list LSobject-list-actions'>
        <?php  $_smarty_tpl->tpl_vars['item'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['item']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['object']->value->actions; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['item']->key => $_smarty_tpl->tpl_vars['item']->value) {
$_smarty_tpl->tpl_vars['item']->_loop = true;
?>
          <a href='<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
'  class='LSobject-list-actions'><img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['item']->value['label'];?>
' title='<?php echo $_smarty_tpl->tpl_vars['item']->value['label'];?>
'/></a>
        <?php } ?>
        </td>
    </tr>
    <?php }
if (!$_smarty_tpl->tpl_vars['object']->_loop) {
?>
      <tr class='LSobject-list'>
        <td colspan='<?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {
echo count($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns)+3;
} else { ?>3<?php }?>' class='LSobject-list-without-result'>
          <?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_no_result;?>

        </td>
      </tr>   
    <?php } ?>
</table>
<span id='LSobject_list_nbresult'><?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_total;?>
</span>
<?php if ($_smarty_tpl->tpl_vars['page']->value['nbPages']>1) {?>
  <p class='LSobject-list-page'>
    
  <?php if ($_smarty_tpl->tpl_vars['page']->value['nbPages']>10) {?>
    <?php if ($_smarty_tpl->tpl_vars['page']->value['nb']>5) {?>
      <?php if ($_smarty_tpl->tpl_vars['page']->value['nb']>$_smarty_tpl->tpl_vars['page']->value['nbPages']-6) {?>
        <?php $_smarty_tpl->tpl_vars['start'] = new Smarty_variable($_smarty_tpl->tpl_vars['page']->value['nbPages']-12, null, 0);?>
       <?php } else { ?>
        <?php $_smarty_tpl->tpl_vars['start'] = new Smarty_variable($_smarty_tpl->tpl_vars['page']->value['nb']-6, null, 0);?>
      <?php }?>
    <?php } else { ?>
      <?php $_smarty_tpl->tpl_vars['start'] = new Smarty_variable(0, null, 0);?>
    <?php }?>
    <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;page=0' class='LSobject-list-page'><</a> 
    <?php  $_smarty_tpl->tpl_vars['i'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['i']->_loop = false;
 $_from = range(0,10); if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['i']->key => $_smarty_tpl->tpl_vars['i']->value) {
$_smarty_tpl->tpl_vars['i']->_loop = true;
?>
      <?php if ($_smarty_tpl->tpl_vars['page']->value['nb']==$_smarty_tpl->tpl_vars['start']->value+$_smarty_tpl->tpl_vars['i']->value) {?>
        <strong class='LSobject-list-page'><?php echo $_smarty_tpl->tpl_vars['page']->value['nb']+1;?>
</strong> 
      <?php } else { ?>
        <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;page=<?php echo $_smarty_tpl->tpl_vars['i']->value+$_smarty_tpl->tpl_vars['start']->value;?>
'  class='LSobject-list-page'><?php echo $_smarty_tpl->tpl_vars['i']->value+$_smarty_tpl->tpl_vars['start']->value+1;?>
</a> 
      <?php }?>
    <?php } ?>
    <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;page=<?php echo $_smarty_tpl->tpl_vars['page']->value['nbPages']-1;?>
' class='LSobject-list-page'>></a> 
  <?php } else { ?>
    <?php if (isset($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage'])) unset($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']);
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['name'] = 'listpage';
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['loop'] = is_array($_loop=$_smarty_tpl->tpl_vars['page']->value['nbPages']) ? count($_loop) : max(0, (int) $_loop); unset($_loop);
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'] = ((int) 1) == 0 ? 1 : (int) 1;
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['show'] = true;
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['max'] = $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['loop'];
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['start'] = $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'] > 0 ? 0 : $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['loop']-1;
if ($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['show']) {
    $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['total'] = min(ceil(($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'] > 0 ? $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['loop'] - $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['start'] : $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['start']+1)/abs($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'])), $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['max']);
    if ($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['total'] == 0)
        $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['show'] = false;
} else
    $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['total'] = 0;
if ($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['show']):

            for ($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['index'] = $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['start'], $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['iteration'] = 1;
                 $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['iteration'] <= $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['total'];
                 $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['index'] += $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'], $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['iteration']++):
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['rownum'] = $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['iteration'];
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['index_prev'] = $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['index'] - $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'];
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['index_next'] = $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['index'] + $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['step'];
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['first']      = ($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['iteration'] == 1);
$_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['last']       = ($_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['iteration'] == $_smarty_tpl->tpl_vars['smarty']->value['section']['listpage']['total']);
?>
      <?php if ($_smarty_tpl->tpl_vars['page']->value['nb']==$_smarty_tpl->getVariable('smarty')->value['section']['listpage']['index']) {?>
        <strong class='LSobject-list-page'><?php echo $_smarty_tpl->tpl_vars['page']->value['nb']+1;?>
</strong> 
      <?php } else { ?>
        <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
&amp;page=<?php echo $_smarty_tpl->getVariable('smarty')->value['section']['listpage']['index'];?>
'  class='LSobject-list-page'><?php echo $_smarty_tpl->getVariable('smarty')->value['section']['listpage']['index']+1;?>
</a> 
      <?php }?>
    <?php endfor; endif; ?>
  <?php }?>
  </p>
<?php }?>
<?php echo $_smarty_tpl->getSubTemplate ('ls:bottom.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>

<?php }} ?>
